GoogleTokenGenerator class

Generates authentication tokens required by the Google Translate API endpoint.

Implemented types

Constructors

GoogleTokenGenerator()
Creates a GoogleTokenGenerator instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateToken(String text) String
Generates and returns a valid token for text.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tokenGen(dynamic a) String
Generates a valid Google Translate request token for the given input.
toString() String
A string representation of this object.
inherited
unsignedRightShift(int a, int b) int
wr(dynamic a, dynamic b) int

Operators

operator ==(Object other) bool
The equality operator.
inherited